searchNodes=[{"doc":"Solvent is an event bus built to be fast and easy-to-use. Publish and subscribe to events here. You can either provide a function to be run, with subscribe/2 and subscribe/3 , or subscribe a module using subscribe/1 . See the docs for Solvent.Subscriber for more information on module subscribers. iex&gt; Solvent . subscribe ( &quot;My first subscriber&quot; , ~r/.*/ , fn event_id -&gt; ...&gt; { :ok , event } = Solvent.EventStore . fetch ( event_id ) ...&gt; ...&gt; # play with the event, and acknowledge it when you&#39;re done ...&gt; ...&gt; Solvent.EventStore . ack ( event_id , &quot;My first subscriber&quot; ) ...&gt; end ) { :ok , &quot;My first subscriber&quot; } It's important to observe that subscriber functions are given the identifier of an event, not the event itself. Also, note that we call Solvent.EventStore.ack/2 once we're done with the event, so that Solvent knows it can clean up the event from the store. Tip Use the Solvent.Subscriber module to make a subscriber that automatically acknowledges events, along with lots of other nice features. Once you have a subscriber, publish an event. Data is optional, only a type is required. This can be any string. I would recommend the CloudEvents format, which starts with a reversed DNS name, and is dot-separated. This will help avoid collisions with events from other applications. iex&gt; Solvent . publish ( &quot;io.github.cantido.myevent.published&quot; , id : &quot;0b06bdb7-06a7-4df9-a825-1fd225ceea43&quot; ) { :ok , &quot;0b06bdb7-06a7-4df9-a825-1fd225ceea43&quot; } Here you can also supply data for the event with the :data option. iex&gt; Solvent . publish ( &quot;io.github.cantido.myevent.published&quot; , data : &quot;Hello, world!&quot; , id : &quot;d0f63676-b853-4f30-8bcf-ea10f2184556&quot; ) { :ok , &quot;d0f63676-b853-4f30-8bcf-ea10f2184556&quot; } This will be available on the :data key of the event object you fetch from Solvent.EventStore . See the Solvent.Event docs for more information on what that struct contains.","ref":"Solvent.html","title":"Solvent","type":"module"},{"doc":"Publish an event to the event bus, triggering all subscriber functions. Only a type (AKA &quot;topic&quot;) is required. All other fields can be supplied using the options. See Solvent.Event for details on what that struct contains. All values given as options are inserted into the event struct. ID values are version 4 UUIDs by default, and you don't need to provide them. Examples Solvent . publish ( &quot;io.github.cantido.documentation.read&quot; ) { :ok , &quot;some-random-uuid&quot; } iex&gt; Solvent . publish ( ...&gt; &quot;io.github.cantido.documentation.read&quot; , ...&gt; id : &quot;read-docs-id&quot; , ...&gt; datacontenttype : &quot;application/json&quot; , ...&gt; data : ~s({&quot;hello&quot;:&quot;world&quot;}) ...&gt; ) { :ok , &quot;read-docs-id&quot; }","ref":"Solvent.html#publish/2","title":"Solvent.publish/2","type":"function"},{"doc":"Subscribe to the event bus. When the first argument is a module, the module is subscribed to the event bus, and the second argument is expected to be a list of options, if it is provided at all. See Solvent.Subscriber for details. If the first argument is a string or regex, then the second argument must be a function, and the function behaves exactly like subscribe/3 but with an auto-generated ID.","ref":"Solvent.html#subscribe/2","title":"Solvent.subscribe/2","type":"function"},{"doc":"Execute a function when an event is published. The match_type argument can be either a string or a regular expression. It is matched with an event's type using the Kernel.=~/2 operator. The function argument will be given the ID of the event. You must fetch the event from Solvent.EventStore if you wish to use it. The ID is optional, and defaults to a version 4 UUID. iex&gt; Solvent . subscribe ( &quot;My subscriber&quot; , &quot;idsubscriber.event.published&quot; , fn event_id -&gt; ...&gt; { :ok , event } = Solvent.EventStore . fetch ( event_id ) ...&gt; # Use the event, then delete it ...&gt; Solvent.EventStore . delete ( event_id ) ...&gt; end ) { :ok , &quot;My subscriber&quot; }","ref":"Solvent.html#subscribe/3","title":"Solvent.subscribe/3","type":"function"},{"doc":"Remove a subscriber.","ref":"Solvent.html#unsubscribe/1","title":"Solvent.unsubscribe/1","type":"function"},{"doc":"The event that subscribers are waiting for. Events in Solvent follow the CloudEvents specification , and the keys in this struct match the attribute names given in the spec. See new/2 for valid values and their defaults.","ref":"Solvent.Event.html","title":"Solvent.Event","type":"module"},{"doc":"Create a new event. Override default values by providing them in opts . Options :id - the event's unique identifier. Default: a new version 4 UUID. :source - the entity that created this event. Default: &quot;Solvent&quot; . :type - also known as a topic, this is the name of the event that occurred. Set by the first argument to this function, but can be overridden. :data - information associated with the event. Default: nil :datacontenttype - a MIME type for the data in :data . Default: nil :dataschema - details on the structure of the value in :data . Default: nil :subject - describes the subject of the event, for example a filename for binary data in :data . Default: nil :time - a timestamp for when the event occurred. Default: DateTime.utc_now() at struct creation time. :extensions - a map of additional properties. Default: %{}","ref":"Solvent.Event.html#new/2","title":"Solvent.Event.new/2","type":"function"},{"doc":"ETS-based storage for Solvent.Event objects. Events are stored using insert/2 , along with an enumerable of subscriber IDs. The event is then stored until all subscribers call ack/2 to acknowledge the event, after which point the event is deleted from the store. The event store is initialized by the Solvent supervisor, so no setup work is necessary to use the store.","ref":"Solvent.EventStore.html","title":"Solvent.EventStore","type":"module"},{"doc":"Acknowledge that a listener has finished processing the event.","ref":"Solvent.EventStore.html#ack/2","title":"Solvent.EventStore.ack/2","type":"function"},{"doc":"Remove an event from storage.","ref":"Solvent.EventStore.html#delete/1","title":"Solvent.EventStore.delete/1","type":"function"},{"doc":"Delete all events from the event store.","ref":"Solvent.EventStore.html#delete_all/0","title":"Solvent.EventStore.delete_all/0","type":"function"},{"doc":"Fetch an event by ID.","ref":"Solvent.EventStore.html#fetch/1","title":"Solvent.EventStore.fetch/1","type":"function"},{"doc":"Insert a new event into storage, along with all listeners that need to acknowledge it before it can be deleted. This does not activate any subscribers, use Solvent.publish/2 for that.","ref":"Solvent.EventStore.html#insert/2","title":"Solvent.EventStore.insert/2","type":"function"},{"doc":"A module shorthand for defining subscribers. Use this module to quickly create a module that can handle Solvent events. defmodule MyModule do use Solvent.Subscriber , match_type : ~r/myevents.*/ def handle_event ( event_id ) do # Fetch and handle your event here end end Then you only need to pass in the module name to Solvent.subscribe/1 , usually done in your application.ex , or wherever your code starts. By default, module subscribers will automatically call Solvent.EventStore.ack/2 once handle_event/1 returns. To disable this feature, set the :auto_ack option to false , and then you can acknowledge the event manually. This module provides an auto_ack/1 function that is compiled with the ID of your handler, so you only need to provide the event ID. defmodule MyModule do use Solvent.Subscriber , match_type : ~r/myevents.*/ , auto_ack : false def handle_event ( event_id ) do # Fetch and handle your event here ack_event ( event_id ) end end Options :id - the ID to give the subscriber function. Defaults to the current module name. :match_type - a string or regex to match event types. Defaults to ~r/.*/ , which will match every event. :auto_ack - automatically call Subscriber.EventStore.ack/1 after handle_event/1 returns. Defaults to true .","ref":"Solvent.Subscriber.html","title":"Solvent.Subscriber","type":"behaviour"},{"doc":"Performs an action when given an event ID.","ref":"Solvent.Subscriber.html#c:handle_event/1","title":"Solvent.Subscriber.handle_event/1","type":"callback"},{"doc":"Returns the value to match event types against. This function is automatically created when you use this module, but you can override it, if you need.","ref":"Solvent.Subscriber.html#c:match_type/0","title":"Solvent.Subscriber.match_type/0","type":"callback"},{"doc":"Returns the current subscriber ID. This function is automatically created when you use this module, but you can override it, if you need.","ref":"Solvent.Subscriber.html#c:subscriber_id/0","title":"Solvent.Subscriber.subscriber_id/0","type":"callback"}]